==> react-planner-1.2.1.tgz: package/lib/components/toolbar/toolbar-button.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

//http://www.cssportal.com/css-tooltip-generator/

var STYLE = {
  width: "30px",
  height: "30px",
  display: "flex",
  alignItems: "center",
  justifyContent: "center",
  marginBottom: "5px",
  fontSize: "25px",
  position: "relative"
};

var STYLE_TOOLTIP = {
  position: "absolute",
  width: "140px",
  color: "#FFFFFF",
  background: "#000000",
  height: "30px",
  lineHeight: "30px",
  textAlign: "center",
  visibility: "visible",
  borderRadius: "6px",
  opacity: "0.8",
  left: "100%",
  top: "50%",
  marginTop: "-15px",
  marginLeft: "15px",
  zIndex: "999",
  fontSize: "12px"
};

var STYLE_TOOLTIP_PIN = {
  position: "absolute",
  top: "50%",
  right: "100%",
  marginTop: "-8px",
  width: "0",
  height: "0",
  borderRight: "8px solid #000000",
  borderTop: "8px solid transparent",
  borderBottom: "8px solid transparent"
};

var ToolbarButton = function (_Component) {
  _inherits(ToolbarButton, _Component);

  function ToolbarButton(props, context) {
    _classCallCheck(this, ToolbarButton);

    var _this = _possibleConstructorReturn(this, (ToolbarButton.__proto__ || Object.getPrototypeOf(ToolbarButton)).call(this, props, context));

    _this.state = { active: false };
    return _this;
  }

  _createClass(ToolbarButton, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var state = this.state,
          props = this.props;

      var color = props.active || state.active ? '#1CA6FC' : '#C2C2C2';

      return _react2.default.createElement(
        "div",
        { style: STYLE,
          onMouseEnter: function onMouseEnter(event) {
            return _this2.setState({ active: true });
          },
          onMouseLeave: function onMouseLeave(event) {
            return _this2.setState({ active: false });
          } },
        _react2.default.createElement(
          "a",
          { href: "javascript:;", style: { color: color, textDecoration: "none" }, onClick: props.onClick },
          props.children
        ),
        state.active ? _react2.default.createElement(
          "div",
          { style: STYLE_TOOLTIP },
          _react2.default.createElement("span", { style: STYLE_TOOLTIP_PIN }),
          props.tooltip
        ) : null
      );
    }
  }]);

  return ToolbarButton;
}(_react.Component);

exports.default = ToolbarButton;


ToolbarButton.propTypes = {
  active: _react.PropTypes.bool.isRequired,
  onClick: _react.PropTypes.func.isRequired,
  tooltip: _react.PropTypes.string.isRequired
};

==> react-planner-1.3.1.tgz: package/lib/components/toolbar/toolbar-button.js <==
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

//http://www.cssportal.com/css-tooltip-generator/

var STYLE = {
  width: "30px",
  height: "30px",
  display: "flex",
  alignItems: "center",
  justifyContent: "center",
  marginBottom: "5px",
  fontSize: "25px",
  position: "relative"
};

var STYLE_TOOLTIP = {
  position: "absolute",
  width: "140px",
  color: "#FFFFFF",
  background: "#000000",
  height: "30px",
  lineHeight: "30px",
  textAlign: "center",
  visibility: "visible",
  borderRadius: "6px",
  opacity: "0.8",
  left: "100%",
  top: "50%",
  marginTop: "-15px",
  marginLeft: "15px",
  zIndex: "999",
  fontSize: "12px"
};

var STYLE_TOOLTIP_PIN = {
  position: "absolute",
  top: "50%",
  right: "100%",
  marginTop: "-8px",
  width: "0",
  height: "0",
  borderRight: "8px solid #000000",
  borderTop: "8px solid transparent",
  borderBottom: "8px solid transparent"
};

var ToolbarButton = function (_Component) {
  _inherits(ToolbarButton, _Component);

  function ToolbarButton(props, context) {
    _classCallCheck(this, ToolbarButton);

    var _this = _possibleConstructorReturn(this, (ToolbarButton.__proto__ || Object.getPrototypeOf(ToolbarButton)).call(this, props, context));

    _this.state = { active: false };
    return _this;
  }

  _createClass(ToolbarButton, [{
    key: 'render',
    value: function render() {
      var _this2 = this;

      var state = this.state,
          props = this.props;

      var color = props.active || state.active ? '#1CA6FC' : '#C2C2C2';

      return _react2.default.createElement(
        'div',
        { style: STYLE,
          onMouseEnter: function onMouseEnter(event) {
            return _this2.setState({ active: true });
          },
          onMouseLeave: function onMouseLeave(event) {
            return _this2.setState({ active: false });
          } },
        _react2.default.createElement(
          'a',
          { href: 'javascript:;', style: { color: color, textDecoration: "none" }, onClick: props.onClick },
          props.children
        ),
        state.active ? _react2.default.createElement(
          'div',
          { style: STYLE_TOOLTIP },
          _react2.default.createElement('span', { style: STYLE_TOOLTIP_PIN }),
          props.tooltip
        ) : null
      );
    }
  }]);

  return ToolbarButton;
}(_react.Component);

exports.default = ToolbarButton;


ToolbarButton.propTypes = {
  active: _propTypes2.default.bool.isRequired,
  onClick: _propTypes2.default.func.isRequired,
  tooltip: _propTypes2.default.string.isRequired
};
